pub struct PagespeedApiFormatStringV4 {
pub args: Option<Vec<PagespeedApiFormatStringV4Args>>,
pub format: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
args: Option<Vec<PagespeedApiFormatStringV4Args>>List of arguments for the format string.
format: Option<String>A localized format string with {{FOO}} placeholders, where ‘FOO’ is the key of the argument whose value should be substituted. For HYPERLINK arguments, the format string will instead contain {{BEGIN_FOO}} and {{END_FOO}} for the argument with key ‘FOO’.