pub struct PagespeedApiFormatStringV4Args {
pub key: Option<String>,
pub rects: Option<Vec<PagespeedApiFormatStringV4ArgsRects>>,
pub secondary_rects: Option<Vec<PagespeedApiFormatStringV4ArgsSecondaryRects>>,
pub type_: Option<String>,
pub value: Option<String>,
}Expand description
List of arguments for the format string.
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>The placeholder key for this arg, as a string.
rects: Option<Vec<PagespeedApiFormatStringV4ArgsRects>>The screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments. If this is absent for a SNAPSHOT_RECT argument, it means that that argument refers to the entire snapshot.
secondary_rects: Option<Vec<PagespeedApiFormatStringV4ArgsSecondaryRects>>Secondary screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments.
type_: Option<String>Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, DURATION, VERBATIM_STRING, PERCENTAGE, HYPERLINK, or SNAPSHOT_RECT.
value: Option<String>Argument value, as a localized string.