pub struct PagespeedApiFormatStringV4ArgsRects {
pub height: Option<i32>,
pub left: Option<i32>,
pub top: Option<i32>,
pub width: Option<i32>,
}Expand description
The screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments. If this is absent for a SNAPSHOT_RECT argument, it means that that argument refers to the entire snapshot.
This type is not used in any activity, and only used as part of another schema.
Fields
height: Option<i32>no description provided
left: Option<i32>no description provided
top: Option<i32>no description provided
width: Option<i32>no description provided