pub struct PagespeedApiFormatStringV4ArgsSecondaryRects {
pub height: Option<i32>,
pub left: Option<i32>,
pub top: Option<i32>,
pub width: Option<i32>,
}Expand description
Secondary screen rectangles being referred to, with dimensions measured in CSS pixels. This is only ever used for SNAPSHOT_RECT arguments.
This type is not used in any activity, and only used as part of another schema.
Fields
height: Option<i32>no description provided
left: Option<i32>no description provided
top: Option<i32>no description provided
width: Option<i32>no description provided